#!/bin/bash

cp /monroe/config /monroe/results/config.txt
paris=`cat /monroe/config | /usr/bin/python -c "import sys, json; variables = json.load(sys.stdin); print variables['paris'] if 'paris' in variables else 'True'"`
tracebox=`cat /monroe/config | /usr/bin/python -c "import sys, json; variables = json.load(sys.stdin); print variables['tracebox'] if 'tracebox' in variables else 'True'"`
http=`cat /monroe/config | /usr/bin/python -c "import sys, json; variables = json.load(sys.stdin); print variables['http'] if 'http' in variables else 'True'"`
duration=`cat /monroe/config | /usr/bin/python -c "import sys, json; variables = json.load(sys.stdin); print variables['duration'] if 'duration' in variables else '10'"`
executions=`cat /monroe/config | /usr/bin/python -c "import sys, json; variables = json.load(sys.stdin); print variables['executions'] if 'executions' in variables else '1'"`
interface=`cat /monroe/config | /usr/bin/python -c "import sys, json; variables = json.load(sys.stdin); print variables['interface'] if 'interface' in variables else ''"`
server=`cat /monroe/config | /usr/bin/python -c "import sys, json; variables = json.load(sys.stdin); print variables['server'] if 'server' in variables else '131.114.58.101'"`

echo "paris: ${paris}" >> /tmp/variables.txt
echo "tracebox: ${tracebox}" >> /tmp/variables.txt
echo "http: ${http}" >> /tmp/variables.txt
echo "duration: ${duration}" >> /tmp/variables.txt
echo "executions: ${executions}" >> /tmp/variables.txt
echo "interface: ${interface}" >> /tmp/variables.txt
echo "server: ${server}" >> tmp/variables.txt
cp /tmp/variables.txt /monroe/results/

echo "[LOG] `date` Starting script" >> /tmp/log.txt
cp /tmp/log.txt /monroe/results/log_01.txt
if [ -z "$interface" ]
then
	interface="op"
fi

if [ "$tracebox" == "True" ]
then
	echo "[LOG] `date` Installing tracebox from deb" >> /tmp/log.txt
	cp /tmp/log.txt /monroe/results/log_02.txt
	ln -s /lib/x86_64-linux-gnu/libjson-c.so.3 /lib/x86_64-linux-gnu/libjson-c.so.2
	apt-get install -y /opt/monroe/tracebox_latest_amd64.deb > /tmp/apt.txt 2>&1
	cp /tmp/apt.txt /monroe/results/
fi

ifconfig > /tmp/ifconfig.txt
cp /tmp/ifconfig.txt /monroe/results/
mawk '/^'${interface}'/ {sub(":", "", $1); print $1}' /tmp/ifconfig.txt > /tmp/ifconfiginterfaces.txt 2>&1
cp /tmp/ifconfiginterfaces.txt /monroe/results/

echo "[LOG] `date` Finished setup"
cp /tmp/log.txt /monroe/results/log_03.txt

for i in `seq ${executions}`
do
	echo "[LOG] `date` Starting execution ${i}/${executions}" >> /tmp/log.txt
	cp /tmp/log.txt /monroe/results/log_04.txt

	while read line
	do
		if [ "$tracebox" == "True" ]
		then
	        	echo "[LOG] `date` Starting tracebox on interface ${line} with port 6881" >> /tmp/log.txt
			cp /tmp/log.txt /monroe/results/log_05.txt
	        	tracebox -i ${line} -d 6881 -m 30 -v -j ${server} > /tmp/tracebox_6881_${line}_${i}.txt 2>&1
	        	echo "[LOG] `date` Starting tracebox on interface ${line} with port 53647" >> /tmp/log.txt
			cp /tmp/log.txt /monroe/results/log_06.txt
	        	tracebox -i ${line} -d 53674 -m 30 -v -j ${server} > /tmp/tracebox_53674_${line}_${i}.txt 2>&1
			# tracebox -i ${line} -s /opt/monroe/tracebox_monroe.lua ${server} > /tmp/tracebox_script_${line}.txt 2>&1
			cp /tmp/tracebox_*_${line}_${i}.txt /monroe/results/
		fi
		if [ "$paris" == "True" ]
		then
	        	echo "[LOG] `date` Starting paris traceroute with MDA on interface ${line}" >> /tmp/log.txt
			cp /tmp/log.txt /monroe/results/log_07.txt
	        	paris-traceroute -O ${line} -a exh ${server} > /tmp/paris_${line}_${i}.txt 2>&1
			cp /tmp/paris_${line}_${i}.txt /monroe/results/
		fi
	        echo "[LOG] `date` Starting neutmon on interface ${line} with duration ${duration}" >> /tmp/log.txt
		cp /tmp/log.txt /monroe/results/log_08.txt
		if [ "$http" == "True" ]
		then
	        	/usr/bin/python -u /opt/monroe/client.py -i "${line}" -m -t -s ${server} -d ${duration} -e ${i} > /tmp/neutmon_output_${line}_${i}.txt 2>&1 &
		else
			/usr/bin/python -u /opt/monroe/client.py -i "${line}" -m -s ${server} -d ${duration} -e ${i} > /tmp/neutmon_output_${line}_${i}.txt 2>&1 &
		fi
		j=1
		while ps aux | grep "[c]lient.py" > /dev/null
		do
			cp /tmp/neutmon_output_${line}_${i}.txt /monroe/results/neutmon_output_${line}_${i}_${j}.txt
			j=$((j+1))
			sleep 30
		done
	        echo "[LOG] `date` Copying log for interface ${line}" >> /tmp/log.txt
		cp /tmp/log.txt /monroe/results/log_09.txt
	        cp /tmp/neutmon_output_${line}_${i}.txt /monroe/results/
	done < /tmp/ifconfiginterfaces.txt
	echo "[LOG] `date` Finishing execution ${i}/${executions}" >> /tmp/log.txt
	cp /tmp/log.txt /monroe/results/log_10.txt
done
echo "[LOG] `date` Finishing" >> /tmp/log.txt
cp /tmp/log.txt /monroe/results/log_11.txt
ifconfig > /tmp/ifconfig2.txt
cp /tmp/log.txt /monroe/results/
cp /tmp/ifconfig2.txt /monroe/results/
